@@ -4,13 +4,13 @@ cat("***********************************************************************","\
 cat("EstCRM -- An R Package for Estimating Samejima's Continuous IRT Model Parameters","\n")
 cat("         ","Via Marginal Maximum Likelihood Estimation and EM Algorithm","\n")
 cat("","\n")
-cat("Version 1.4  2015","\n")
+cat("Version 1.6  2022","\n")
 cat("","\n")
 cat("Cengiz Zopluoglu","\n")
 cat("","\n")
-cat("University of Miami - Educational and Psychological Studies","\n")
+cat("University of Oregon - College of Education","\n")
 cat("","\n")
-cat("c.zopluoglu@miami.edu","\n")
+cat("cengiz@uoregon.edu","\n")
 cat("*************************************************************************","\n")
 cat("Please use the following citation for any use of the package in any","\n")
 cat("publication:","\n")
